@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 our $DATE = '2015-04-24'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -29,7 +29,7 @@ our $funcset_re     = qr/\A(?:[A-Za-z_]\w*::)*[A-Za-z_]\w*\z/;
 our $compiler_re    = qr/\A[A-Za-z_]\w*\z/;
 our $clause_attr_on_empty_clause_re = qr/\A(?:\.[A-Za-z_]\w*)+\z/;
 
-sub normalize_clset {
+sub normalize_clset($;$) {
     my ($clset0, $opts) = @_;
     $opts //= {};
 
@@ -130,8 +130,8 @@ sub normalize_clset {
     $clset;
 }
 
-sub normalize_schema {
-    my ($s) = @_;
+sub normalize_schema($) {
+    my $s = shift;
 
     my $ref = ref($s);
     if (!defined($s)) {
@@ -207,7 +207,7 @@ Data::Sah::Normalize - Normalize Sah schema
 
 =head1 VERSION
 
-This document describes version 0.02 of Data::Sah::Normalize (from Perl distribution Data-Sah-Normalize), released on 2015-04-24.
+This document describes version 0.03 of Data::Sah::Normalize (from Perl distribution Data-Sah-Normalize), released on 2015-04-24.
 
 =head1 SYNOPSIS
 
